@@ -352,7 +352,16 @@ extern void e_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_BOOLEAN	e_marshal_VOID__OBJECT_BOOLEAN
 
-/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:42) */
+/* NONE:OBJECT,INT (e-marshal.list:42) */
+extern void e_marshal_VOID__OBJECT_INT (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
+#define e_marshal_NONE__OBJECT_INT	e_marshal_VOID__OBJECT_INT
+
+/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:43) */
 extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -361,7 +370,7 @@ extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_DOUBLE_DOUBLE_BOOLEAN	e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN
 
-/* NONE:OBJECT,OBJECT (e-marshal.list:43) */
+/* NONE:OBJECT,OBJECT (e-marshal.list:44) */
 extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -370,7 +379,7 @@ extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_OBJECT	e_marshal_VOID__OBJECT_OBJECT
 
-/* NONE:OBJECT,STRING (e-marshal.list:44) */
+/* NONE:OBJECT,STRING (e-marshal.list:45) */
 extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -379,7 +388,7 @@ extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING	e_marshal_VOID__OBJECT_STRING
 
-/* NONE:OBJECT,STRING,UINT (e-marshal.list:45) */
+/* NONE:OBJECT,STRING,UINT (e-marshal.list:46) */
 extern void e_marshal_VOID__OBJECT_STRING_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -388,7 +397,7 @@ extern void e_marshal_VOID__OBJECT_STRING_UINT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING_UINT	e_marshal_VOID__OBJECT_STRING_UINT
 
-/* NONE:POINTER,INT (e-marshal.list:46) */
+/* NONE:POINTER,INT (e-marshal.list:47) */
 extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -397,7 +406,7 @@ extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT	e_marshal_VOID__POINTER_INT
 
-/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:47) */
+/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:48) */
 extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -406,7 +415,7 @@ extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_INT_INT_INT	e_marshal_VOID__POINTER_INT_INT_INT_INT
 
-/* NONE:POINTER,INT,OBJECT (e-marshal.list:48) */
+/* NONE:POINTER,INT,OBJECT (e-marshal.list:49) */
 extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -415,7 +424,7 @@ extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_OBJECT	e_marshal_VOID__POINTER_INT_OBJECT
 
-/* NONE:POINTER,OBJECT (e-marshal.list:49) */
+/* NONE:POINTER,OBJECT (e-marshal.list:50) */
 extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -424,7 +433,7 @@ extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_OBJECT	e_marshal_VOID__POINTER_OBJECT
 
-/* NONE:POINTER,POINTER (e-marshal.list:50) */
+/* NONE:POINTER,POINTER (e-marshal.list:51) */
 extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -433,7 +442,7 @@ extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER	e_marshal_VOID__POINTER_POINTER
 
-/* NONE:POINTER,POINTER,INT (e-marshal.list:51) */
+/* NONE:POINTER,POINTER,INT (e-marshal.list:52) */
 extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -442,7 +451,7 @@ extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER_INT	e_marshal_VOID__POINTER_POINTER_INT
 
-/* NONE:STRING,DOUBLE (e-marshal.list:52) */
+/* NONE:STRING,DOUBLE (e-marshal.list:53) */
 extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -451,7 +460,7 @@ extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_DOUBLE	e_marshal_VOID__STRING_DOUBLE
 
-/* NONE:STRING,INT (e-marshal.list:53) */
+/* NONE:STRING,INT (e-marshal.list:54) */
 extern void e_marshal_VOID__STRING_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -460,7 +469,7 @@ extern void e_marshal_VOID__STRING_INT (GClosure     *closure,
                                         gpointer      marshal_data);
 #define e_marshal_NONE__STRING_INT	e_marshal_VOID__STRING_INT
 
-/* NONE:STRING,INT,INT (e-marshal.list:54) */
+/* NONE:STRING,INT,INT (e-marshal.list:55) */
 extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -469,7 +478,7 @@ extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__STRING_INT_INT	e_marshal_VOID__STRING_INT_INT
 
-/* NONE:STRING,OBJECT (e-marshal.list:55) */
+/* NONE:STRING,OBJECT (e-marshal.list:56) */
 extern void e_marshal_VOID__STRING_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -478,7 +487,7 @@ extern void e_marshal_VOID__STRING_OBJECT (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_OBJECT	e_marshal_VOID__STRING_OBJECT
 
-/* NONE:STRING,POINTER,POINTER (e-marshal.list:56) */
+/* NONE:STRING,POINTER,POINTER (e-marshal.list:57) */
 extern void e_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -487,7 +496,7 @@ extern void e_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
                                                     gpointer      marshal_data);
 #define e_marshal_NONE__STRING_POINTER_POINTER	e_marshal_VOID__STRING_POINTER_POINTER
 
-/* NONE:STRING,STRING (e-marshal.list:57) */
+/* NONE:STRING,STRING (e-marshal.list:58) */
 extern void e_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -496,7 +505,7 @@ extern void e_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_STRING	e_marshal_VOID__STRING_STRING
 
-/* NONE:UINT,STRING (e-marshal.list:58) */
+/* NONE:UINT,STRING (e-marshal.list:59) */
 extern void e_marshal_VOID__UINT_STRING (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -505,7 +514,7 @@ extern void e_marshal_VOID__UINT_STRING (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__UINT_STRING	e_marshal_VOID__UINT_STRING
 
-/* STRING:NONE (e-marshal.list:59) */
+/* STRING:NONE (e-marshal.list:60) */
 extern void e_marshal_STRING__VOID (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
