@@ -26,8 +26,6 @@
 #include <sys/types.h>
 #include <gtk/gtk.h>
 #include <camel/camel.h>
-#include <libedataserver/e-proxy.h>
-#include <libedataserver/e-account.h>
 
 #include <libemail-engine/e-mail-session.h>
 #include <libemail-engine/e-mail-utils.h>
@@ -37,7 +35,7 @@
 
 G_BEGIN_DECLS
 
-struct _EMFormat;
+struct _EMailPartList;
 struct _EShell;
 
 gboolean em_utils_ask_open_many (GtkWindow *parent, gint how_many);
@@ -68,19 +66,14 @@ void em_utils_selection_get_urilist (GtkSelectionData *data, CamelFolder *folder
 EProxy *	em_utils_get_proxy		(void);
 
 /* FIXME: should this have an override charset? */
-gchar *em_utils_message_to_html (CamelMimeMessage *msg, const gchar *credits, guint32 flags, struct _EMFormat *source, const gchar *append, guint32 *validity_found);
+gchar *em_utils_message_to_html (CamelSession *session, CamelMimeMessage *msg, const gchar *credits, guint32 flags, struct _EMailPartList *parts_list, const gchar *append, guint32 *validity_found);
 
 void		em_utils_empty_trash		(GtkWidget *parent,
 						 EMailSession *session);
 
-/* clears flag 'get_password_canceled' at every known accounts, so if needed, get_password will show dialog */
-void em_utils_clear_get_password_canceled_accounts_flag (void);
-
 /* Unescapes &amp; back to a real & in URIs */
 gchar *em_utils_url_unescape_amp (const gchar *url);
 
-void emu_free_mail_account_sort_order_cache (void);
-
 void emu_restore_folder_tree_state (EMFolderTree *folder_tree);
 
 gboolean em_utils_is_re_in_subject (struct _EShell *shell,
